// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <ClanLib/clanlayer2.h>

#include "plf_datatypes.hh"
#include "pingu.hh"
#include "button_panel.hh"
#include "actions/pingu_actions.hh"

CL_ResourceManager* ButtonPanel::resource = 0;
CL_Surface* ButtonPanel::button_cap;
//CL_Font*    ButtonPanel::font;

ButtonPanel::ButtonPanel(PLF* plf)
{
  need_redraw = true;
  pressed_button = 2;

  vector<button_data> buttons = plf->get_buttons();

  for(int i=0; i < buttons.size(); ++i) {
    button.push_back(new Button(38 * i, 424, buttons[i].name,
				buttons[i].make_action, resource));
  }
}

ButtonPanel::~ButtonPanel()
{
}

void
ButtonPanel::let_move() 
{
  for(int i=0; i < button.size(); ++i) {
    button[i]->let_move();
  }

  if (CL_Mouse::get_y() > 424 && CL_Mouse::left_pressed()) {
    for(int i=0; i < button.size(); ++i) {
      if (CL_Mouse::get_x() >= i * 38 && CL_Mouse::get_x() < ((i + 1) * 38)) {
	pressed_button = i;
	break;
      }
    }
  }
}

PinguAction*
ButtonPanel::get_action()
{
  return button[pressed_button]->get_action();
  //  return button[pressed_button]->get_action();
  /*
  switch(pressed_button) {
  case 0:
    return new Bomber;
  case 1:
    return new Bridger;
  case 2:
    return new Blocker;
  case 3:
    return new Digger;
  case 4:
    return new Floater;
  case 5:
    return new Miner;
  default:
    return 0;
    }*/
}

void 
ButtonPanel::draw() 
{
  need_redraw = true;
  if (need_redraw) {
    // draw the buttons
    for(int i=0; i < button.size(); ++i) {
      button[i]->draw();
    }
    need_redraw = false;
  }

  // draw the capture rectangle for the active button
  button_cap->put_screen(pressed_button*38, 424);
}

void
ButtonPanel::load_data(CL_ResourceManager* res)
{
  resource = res;
  button_cap      = CL_Res_Surface::load("Buttons/button_cap", *resource);
  //  font            = CL_Res_Font::load("Fonts/font", *resource);
}

/* EOF */
