// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef WORLD_HH
#define WORLD_HH

#include <ClanLib/clanlib.h>
#include <vector>

#include "plf.hh"
#include "pingu.hh"
#include "background.hh"
#include "colmap.hh"
#include "entrance.hh"
#include "exit.hh"
#include "hotspot.hh"
#include "trap.hh"
#include "traps/traps.hh"
#include "result.hh"

// World holds all object of the pingu world (pingus, traps, exits,
// entrances, etc.). It keeps control that all objects become time to
// move and can catch each other. 
class World
{
private:
  PinguMap*  map;
  Background* bg;
  int x_offset;
  int y_offset;
  int released_pingus;
  int allowed_pingus;
  Result* result;

  vector<Entrance*> entrance;
  vector<Exit*>     exits;

  vector<Hotspot*>  hotspot_fg;
  vector<Hotspot*>  hotspot_bg;

  vector<Trap*>   traps;
  
  CL_InputSourceProvider* datafile;

public:
  World();
  ~World();

  void draw_offset(int x, int y);
  void draw_background();
  void draw_pingus();
  void draw_playground();
  void draw_foreground();
  void save();
  void load();
  void load_data(CL_InputSourceProvider*);
  void init(PLF*, Result&);
  void let_move();
  int  get_height();
  int  get_width();
  void write_results();
  vector<Pingu*>* get_pingu_p();

  ColMap colmap;
  static void load_data(CL_ResourceManager*);
  static CL_ResourceManager* resource;
  vector<Pingu*> pingu;
};

#endif

/* EOF */
